#!/bin/bash

##
### works on debian and rhel based systems
### prerequisite packages: wget, gunzip
##


##paketu checkas
check_command() {
    command -v "$1" >/dev/null 2>&1 || { echo >&2 "$1 is required but not installed. Aborting. Install required packages and start again"; exit 1; }
}

check_command wget
check_command gunzip


##ip checkas
validate_ipv4() {
    local ip=$1
    if [[ $ip =~ ^([0-9]{1,3}\.){3}[0-9]{1,3}$ ]]; then
        local IFS='.'
        ip=($ip)
        [[ ${ip[0]} -le 255 && ${ip[1]} -le 255 \
            && ${ip[2]} -le 255 && ${ip[3]} -le 255 ]]
        return $?
    else
        return 1
    fi
}
read -p "Enter the IP address to allow access to the router: " router_ip
if ! validate_ipv4 "$router_ip"; then
    echo "Error: Invalid IPv4 address."
    exit 1
fi


##password checkas
get_admin_password() {
    read -sp "Enter admin password: " admin_password
    echo
    while [ -z "$admin_password" ]; do
        read -sp "Admin password cannot be blank. Please enter again: " admin_password
        echo
    done
}
get_admin_password

##MK installas
wget https://cdn.mikrotik.com/routeros/7.14.2/chr-7.14.2.img.zip -O chr.img.zip

gunzip -c chr.img.zip > chr.img

mount -o loop,offset=33571840 chr.img /mnt

INTERFACE=$(ip route | grep default | awk '{print $5}')
ADDRESS=$(ip addr show $INTERFACE | grep global | cut -d' ' -f 6 | head -n 1)
GATEWAY=$(ip route list | grep default | cut -d' ' -f 3)
DISK_DEVICE=$(fdisk -l | grep "^Disk /dev" | grep -v "^Disk /dev/loop" | cut -d' ' -f2 | tr -d ':')

cat > /mnt/rw/autorun.scr <<EOF
/ip firewall filter add action=accept chain=input connection-state=established,related
/ip firewall filter add action=accept chain=input protocol=icmp
/ip firewall filter add action=accept chain=input src-address-list=allowed_to_router
/ip firewall filter add action=drop chain=input
/ip firewall address-list add address=$router_ip list=allowed_to_router
/ip service set telnet disabled=yes
/ip service set ftp disabled=yes
/ip service set www disabled=yes
/ip service set ssh disabled=yes
/ip service set api disabled=yes
/ip service set api-ssl disabled=yes
/user set admin password=$admin_password
EOF

umount /mnt

dd if=chr.img of=$DISK_DEVICE bs=4M oflag=sync

echo 1 > /proc/sys/kernel/sysrq
echo b > /proc/sysrq-trigger